//+------------------------------------------------------------------+
//|                                                       SMA_en.mq5 |
//|                        Copyright 2009, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
//---- Drawing the indicator in the main window
#property indicator_chart_window
//---- One buffer is used for calculating and rendering the indicator
#property indicator_buffers 1
//---- Only one graphical plotting is used
#prop erty indicator_plots   1
//---- Drawing the indicator as line
#property indicator_type1   DRAW_LINE
//---- Red is used as indicator's line color
#property indicator_color1  Red

//---- Input parameters of indicator
input int MAPeriod=13; // Moving Average period
input int MAShift=0;   // Moving Average horizontal shift in bars

//---- Declaration of dynamic array, which will be 
//     used later as indicator buffer
double ExtLineBuffer[];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+  
void OnInit()
  {
//----+
//---- Transformation of ExtLineBuffer dynamic array into indicator buffer
   SetIndexBuffer(0,ExtLineBuffer,INDICATOR_DATA);
//---- Horizontal shift of Moving Average by MAShift
   PlotIndexSetInteger(0,PLOT_SHIFT,MAShift);
//---- Setting the position from which the drawing of indicator will start
   PlotIndexSetInteger(0,PLOT_DRAW_BEGIN,MAPeriod);
//----+
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+  
void OnDeinit(const int reason)
  {
//----+
//----+
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate
(
 const int rates_total,     // amount of history in bars at the current tick
 const int prev_calculated, // amount of history in bars at the previous tick
 const int begin,           // beginning number reliable count of bars
 const double &price[]      // price array for indicator calculation
 )
  {
//----+   
//---- Check if the number of bars is sufficient for calculation
   if(rates_total<MAPeriod-1+begin)
      return(0);

//---- Declaring local variables
   int first,bar,iii;
   double Sum,SMA;

//---- Calculating the 'first' starting number for the bars recalculation loop
   if(prev_calculated==0)        // Checking the first start of the indicator calculation
      first=MAPeriod-1+begin;    // Starting number for calculation of all bars
   else first=prev_calculated-1; // Starting number for calculation of new bars

//---- Main loop of indicator calculation
   for(bar=first; bar<rates_total; bar++)
     {
      Sum=0.0;
      //---- Loop of price values summation for averaging at the current bar
      for(iii=0; iii<MAPeriod; iii++)
         Sum+=price[bar-iii];    // Sum = Sum + price[bar - iii]; // equivalent of string

      //---- Getting the average
      SMA=Sum/MAPeriod;

      //---- Indicator buffer's cell initialization with SMA value
      ExtLineBuffer[bar]=SMA;
     }
//----+     
   return(rates_total);
  }
//+------------------------------------------------------------------+
